@@ -8,33 +8,33 @@
  work, as well as functions which operate on them.
 """
 from types import FunctionType as Function
-from typing import Any, Dict, List, Optional, Type, TypeVar, Union
+from typing import Any, Dict, List, Type, TypeVar, Union
 
 DataClass = Any  # type hint for variables that should be data class instances
 
 
-class Hint:
-    """A type hint "wrapper". Wraps the actual type of a field to convey information about how it is intended
-    to be used, much like typing.ClassVar. Usage is like Hint[some_type]."""
+class Hint(type):
+    """Metaclass for a type hint "wrapper". Wraps the actual type of a field to convey information about how it is
+    intended to be used, much like typing.ClassVar. Usage is like Hint[some_type].
+    This is a metaclass because __class_getitem__ is not recognised in Python 3.6."""
     Wrapped = TypeVar('Wrapped')
 
-    def __class_getitem__(cls, item: Wrapped) -> Union['Hint', Wrapped]:
+    def __getitem__(cls, item: Wrapped) -> Union['Hint', Wrapped]:
         """Create a new Union of the wrapper and the wrapped type. Union is smart enough to flatten nested
         unions automatically."""
         return Union[cls, item]
 
-    @classmethod
     def is_hinted(cls, hint: Union[Type, str]) -> bool:
         """Check whether a type hint represents this Hint."""
-        return (hasattr(hint, '__args__') and cls in hint.__args__ or
+        return ((hasattr(hint, '__args__') and cls in (hint.__args__ or [])) or
                 (type(hint) is str and f'{cls.__name__}[' in hint))
 
 
-class Internal(Hint):
+class Internal(metaclass=Hint):
     """Marks that a field is internal to the class and so should not in a repr."""
 
 
-class Hashed(Hint):
+class Hashed(metaclass=Hint):
     """Marks that a field should be included in the generated __hash__."""
 
 
